===
API
===

Core Data
=========

.. automodapi:: glue.core.component
   :no-inheritance-diagram:

.. automodapi:: glue.core.component_id
   :no-inheritance-diagram:

.. automodapi:: glue.core.component_link
   :no-inheritance-diagram:

.. automodapi:: glue.core.coordinates
   :no-inheritance-diagram:

.. automodapi:: glue.core.data
   :no-inheritance-diagram:

.. automodapi:: glue.core.data_collection
   :no-inheritance-diagram:

.. automodapi:: glue.core.hub
   :no-inheritance-diagram:

.. automodapi:: glue.core.subset
   :no-inheritance-diagram:

.. automodapi:: glue.core.subset_group
   :no-inheritance-diagram:

.. automodapi:: glue.core.roi
   :no-inheritance-diagram:

.. automodapi:: glue.core.link_helpers
   :no-inheritance-diagram:

.. automodapi:: glue.core.data_factories
   :no-inheritance-diagram:

.. automodapi:: glue.core.fitters
   :no-inheritance-diagram:

.. automodapi:: glue.core.state_objects
   :no-inheritance-diagram:

.. automodapi:: glue.core.exceptions
   :no-inheritance-diagram:

.. automodapi:: glue.core.session
   :no-inheritance-diagram:

User Interface
==============

.. automodapi:: glue.viewers.common.viewer
   :no-inheritance-diagram:

.. automodapi:: glue.viewers.matplotlib.state
   :no-inheritance-diagram:

.. automodapi:: glue.viewers.matplotlib.layer_artist
   :no-inheritance-diagram:

.. automodapi:: glue.core.layer_artist
   :no-inheritance-diagram:

.. automodapi:: glue.viewers.common.state
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.common.layer_artist
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.common.tool
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.matplotlib.mouse_mode
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.matplotlib.toolbar_mode
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.matplotlib.mpl_axes
   :no-inheritance-diagram:

.. automodapi:: glue.viewers.matplotlib.viewer
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.scatter.viewer
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.scatter.state
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.profile.viewer
  :no-inheritance-diagram:
  :inherited-members:

.. automodapi:: glue.viewers.profile.state
  :no-inheritance-diagram:
  :inherited-members:

.. automodapi:: glue.viewers.image.viewer
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.image.state
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.viewers.histogram.viewer
   :no-inheritance-diagram:

.. automodapi:: glue.viewers.histogram.state
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: glue.core.application_base
   :no-inheritance-diagram:

.. automodapi:: glue
   :no-inheritance-diagram:

Utilities
=========

.. automodapi:: glue.config
   :no-inheritance-diagram:

.. automodapi:: glue.core.simpleforms
   :no-inheritance-diagram:

.. automodapi:: glue.core.data_combo_helper
  :no-inheritance-diagram:

.. automodapi:: glue.core.message
   :no-inheritance-diagram:

.. automodapi:: glue.core.util
   :no-inheritance-diagram:

.. automodapi:: glue.core.visual
   :no-inheritance-diagram:

.. automodapi:: glue.utils.array
   :no-inheritance-diagram:

.. automodapi:: glue.utils.geometry
   :no-inheritance-diagram:

.. automodapi:: glue.utils.matplotlib
   :no-inheritance-diagram:

.. automodapi:: glue.utils.misc
   :no-inheritance-diagram:

Plugins
=======

.. automodapi:: glue.plugins.wcs_autolinking.wcs_autolinking
   :no-inheritance-diagram:
